@@ -1,19 +1,25 @@
 from .agents import AgentCode, AgentTool
 from .classes import (
     AgentRequest,
-    AgentSettings,
-    ContainerSettings,
-    ContainerUploadSettings,
     Document,
     DocumentRequest,
     ExtractedField,
     GroundXDocument,
-    GroundXSettings,
     ProcessResponse,
     Prompt,
+    TestChunk,
+    TestDocumentPage,
+    TestField,
+    TestXRay,
     XRayDocument,
 )
 from .services import Logger, RateLimit, SheetsClient, Status, Upload
+from .settings import (
+    AgentSettings,
+    ContainerSettings,
+    ContainerUploadSettings,
+    GroundXSettings,
+)
 
 __all__ = [
     "AgentCode",
@@ -33,6 +39,10 @@ __all__ = [
     "RateLimit",
     "SheetsClient",
     "Status",
+    "TestChunk",
+    "TestDocumentPage",
+    "TestField",
+    "TestXRay",
     "Upload",
     "XRayDocument",
 ]
